@@ -92,14 +92,14 @@ n.write_to_file(filename="output.nex", interleave=True, charblock=True)
 
 """
 __author__ = 'Simon Greenhill <simon@simon.net.nz>'
-__version__ = "1.5"
+__version__ = "1.6"
 PACKAGE_NAME = "python-nexus"
 PACKAGE_VERSION = __version__
 VERSION = __version__
 PACKAGE_AUTHOR = "Simon J. Greenhill"
-PACKAGE_COPYRIGHT = "Copyright 2009-2016 Simon J. Greenhill"
+PACKAGE_COPYRIGHT = "Copyright 2009-2018 Simon J. Greenhill"
 PACKAGE_LICENSE = """
-Copyright (c) 2009-2016, Simon J. Greenhill
+Copyright (c) 2009-2018, Simon J. Greenhill
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification
@@ -128,8 +128,9 @@ ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-from .reader import NexusFormatException, NexusReader
-from .writer import NexusWriter
-from . import tools
+from nexus.reader import NexusReader
+from nexus.writer import NexusWriter
+from nexus.handlers import NexusFormatException
+from nexus import tools
 
 __all__ = ["NexusReader", "NexusWriter", "NexusFormatException", "tools"]
