@@ -3,9 +3,11 @@ from __future__ import division, print_function
 import sys
 from nexus import NexusReader, VERSION
 from nexus.tools import count_site_values
+from nexus.tools import check_zeros
 from nexus.tools import find_constant_sites
 from nexus.tools import find_unique_sites
 from nexus.tools import new_nexus_without_sites
+from nexus.bin.nexus_treemanip import parse_deltree
 
 __author__ = 'Simon Greenhill <simon@simon.net.nz>'
 __doc__ = """nexusmanip - python-nexus tools v%(version)s
@@ -14,7 +16,7 @@ Performs a number of nexus manipulation methods.
 """ % {'version': VERSION, }
 
 
-def print_site_values(nexus_obj, characters=['-', '?']):
+def print_site_values(nexus_obj, characters=None):
     """
     Prints out counts of the number of sites with state in `characters` in a
     nexus.
@@ -24,6 +26,8 @@ def print_site_values(nexus_obj, characters=['-', '?']):
     :param nexus_obj: A `NexusReader` instance
     :type nexus_obj: NexusReader
     """
+    characters = characters if characters is not None else ['-', '?']
+    
     count = count_site_values(nexus_obj, characters)
     print ("Number of %s in %s" % (",".join(characters), nexus_obj.filename))
     for taxon in sorted(count):
@@ -79,6 +83,12 @@ if __name__ == '__main__':
     parser.add_option("-u", "--unique", dest="unique",
             action="store_true", default=False,
             help="Remove the unique characters")
+    parser.add_option("-x", "--remove", dest="remove",
+            action="store", default=False,
+            help="Remove the empty characters")
+    parser.add_option("-z", "--zeros", dest="zeros",
+            action="store_true", default=False,
+            help="Remove the empty characters")
     parser.add_option("-s", "--stats", dest="stats",
             action="store_true", default=False,
             help="Print character-by-character stats")
@@ -102,28 +112,30 @@ if __name__ == '__main__':
     newnexus = None
 
     if options.number:
-        if newnexusname is not None:
-            print_site_values(nexus, newnexusname)
-        else:
-            print_site_values(nexus)
-
-    elif options.constant:
-        const = find_constant_sites(nexus)
-        newnexus = new_nexus_without_sites(nexus, const)
-        print("Constant Sites: %s" % ",".join([str(i) for i in const]))
-    elif options.unique:
-        unique = find_unique_sites(nexus)
-        newnexus = new_nexus_without_sites(nexus, unique)
-        print("Unique Sites: %s" % ",".join([str(i) for i in unique]))
-    elif options.stats:
-        d = print_character_stats(nexus)
-
-    else:
+        print_site_values(nexus)
         exit()
-
+    
+    if options.stats:
+        print_character_stats(nexus)
+        exit()
+        
+    const, unique, zeros, remove = [], [], [], []
+    if options.constant:
+        const = find_constant_sites(nexus)
+        print("Constant Sites: %s" % ",".join([str(i) for i in const]))
+    if options.unique:
+        unique = find_unique_sites(nexus)
+        print("Unique Sites: %s" % ",".join([str(i) for i in unique]))
+    if options.zeros:
+        zeros = check_zeros(nexus)
+        print("Zero Sites: %s" % ",".join([str(i) for i in zeros]))
+    if options.remove:
+        remove = [int(i) for i in parse_deltree(options.remove)]
+        print("Remove: %s" % ",".join([str(i) for i in zeros]))
+        
+    newnexus = new_nexus_without_sites(nexus, set(const + unique + zeros + remove))
+    
     # check for saving
     if newnexus is not None and newnexusname is not None:
         newnexus.write_to_file(newnexusname)
         print("New nexus written to %s" % newnexusname)
-
-
