@@ -2,7 +2,8 @@
 import sys
 from random import sample
 
-from nexus import NexusReader, VERSION, NexusFormatException
+from nexus import NexusReader, VERSION
+from nexus.handlers import NexusFormatException
 from nexus.tools import check_for_valid_NexusReader
 
 
@@ -28,12 +29,6 @@ Remove comments:
     nexus_treemanip.py -c old.trees new.trees
 """
 
-class TreeListException(NexusFormatException):
-    """Generic Exception for Tree Lists"""
-    def __init__(self, arg):
-        Exception.__init__(self, arg)
-        self.arg = arg
-
 def parse_deltree(dstring):
     """
     Returns a list of trees to be deleted
@@ -42,27 +37,22 @@ def parse_deltree(dstring):
     :type dstring: string
 
     :return: A list of trees to be deleted.
-    :raises TreeListException: if dstring is invalid.
+    :raises ValueError: if a component of dstring is not an integer.
+    """
+    def _int(v):
+        try:
+            return int(v)
+        except ValueError:
+            raise ValueError("%r is not an integer" % v)
     
-   """
     out = []
     for token in dstring.split(','):
         token = token.replace(':', '-')
         if '-' in token:
-            try:
-                start, stop = token.split("-")
-                out.extend([x for x in range(int(start), int(stop) + 1)])
-            except (ValueError, IndexError):
-                raise TreeListException(
-                    "'%s' is not a valid token for a tree list" % token
-                )
+            start, stop = token.split("-")
+            out.extend([x for x in range(_int(start), _int(stop) + 1)])
         else:
-            try:
-                out.append(int(token))
-            except (ValueError):
-                raise TreeListException(
-                    "'%s' is not a valid token for a tree list" % token
-                )
+            out.append(_int(token))
     return sorted(out)
 
 
@@ -89,12 +79,12 @@ def run_deltree(deltree, nexus_obj, do_print=False):
     new = []
     delitems = parse_deltree(deltree)
 
-    if do_print:
+    if do_print:  # pragma: no cover
         print('Deleting: %d trees' % len(delitems))
 
     for index, tree in enumerate(nexus_obj.trees, 1):
         if index in delitems:
-            if do_print:
+            if do_print:  # pragma: no cover
                 print('Deleting tree %d' % index)
         else:
             new.append(tree)
@@ -125,12 +115,12 @@ def run_resample(resample, nexus_obj, do_print=False):
     new = []
     try:
         every = int(resample)
-    except ValueError:
-        sys.exit(
+    except TypeError:
+        raise ValueError(
             "Invalid resample option %s - should be an integer" % resample
         )
 
-    if do_print:
+    if do_print:  # pragma: no cover
         print('Resampling ever %d trees' % every)
 
     ignore_count = 0
@@ -140,7 +130,7 @@ def run_resample(resample, nexus_obj, do_print=False):
         else:
             ignore_count += 1
 
-    if do_print:
+    if do_print:  # pragma: no cover
         print("Ignored %d trees" % ignore_count)
 
     nexus_obj.trees.trees = new
@@ -164,25 +154,22 @@ def run_removecomments(nexus_obj, do_print=False):
     check_for_valid_NexusReader(nexus_obj, required_blocks=['trees'])
 
     new = []
-    for index, tree in enumerate(nexus_obj.trees, 1):
+    for tree in nexus_obj.trees:
         new.append(nexus_obj.trees.remove_comments(tree))
 
-    if do_print:
+    if do_print:  # pragma: no cover
         print("Removed comments")
 
     nexus_obj.trees.trees = new
     return nexus_obj
 
-def run_detranslate(nexus_obj, do_print=False):
+def run_detranslate(nexus_obj):
     """
     Removes comments from the trees in a nexus
 
     :param nexus_obj: A `NexusReader` instance
     :type nexus_obj: NexusReader
 
-    :param do_print: flag to print() logging information or not
-    :type do_print: Boolean
-
     :return: A NexusReader instance with the comments removed.
 
     :raises AssertionError: if nexus_obj is not a nexus
@@ -220,10 +207,10 @@ def run_random(num_trees, nexus_obj, do_print=False):
         raise ValueError(
             "Treefile only has %d trees in it." % nexus_obj.trees.ntrees
         )
-    elif num_trees == nexus_obj.trees.ntrees:
+    elif num_trees == nexus_obj.trees.ntrees:  # pragma: no cover
         return nexus_obj  # um. ok.
     else:
-        if do_print:
+        if do_print:  # pragma: no cover
             print(
                 "%d trees read. Sampling %d" %
                 (nexus_obj.trees.ntrees, num_trees)
@@ -232,7 +219,7 @@ def run_random(num_trees, nexus_obj, do_print=False):
     return nexus_obj
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     #set up command-line options
     from optparse import OptionParser
     parser = OptionParser(usage="usage: %prog old.trees new.trees")
@@ -298,7 +285,7 @@ if __name__ == '__main__':
 
     # detranslate
     if options.detranslate:
-        nexus = run_detranslate(nexus, options.quiet)
+        nexus = run_detranslate(nexus)
 
     if newnexus is not None:
         nexus.write_to_file(newnexus)
@@ -309,4 +296,3 @@ if __name__ == '__main__':
             )
     else:
         print(nexus.write())
-
