@@ -26,6 +26,7 @@ class NexusWriter:
 
     def __init__(self):
         self.comments = []
+        self._taxa = None
         self.data = collections.defaultdict(dict)
         self.is_binary = False
 
@@ -46,10 +47,11 @@ class NexusWriter:
         return self.data.keys()
     
     @property
-    def taxalist(self):
-        t = set()
-        [t.update(self.data[c].keys()) for c in self.data]
-        return t
+    def taxa(self):
+        if self._taxa is None:
+            self._taxa = set()
+            [self._taxa.update(self.data[c].keys()) for c in self.data]
+        return self._taxa
     
     @property
     def symbols(self):
@@ -69,19 +71,19 @@ class NexusWriter:
 
     def _make_matrix_block(self, interleave):
         """Generates a matrix block"""
-        max_taxon_size = max([len(t) for t in self.taxalist]) + 3
+        max_taxon_size = max([len(t) for t in self.taxa]) + 3
         
         out = []
         if interleave:
             for c in sorted(self.characters):
-                for t in self.taxalist:
+                for t in self.taxa:
                     out.append(
                         "%s %s" % (t.ljust(max_taxon_size),
                                    self.data[c].get(t, self.MISSING))
                     )
                 out.append("")
         else:
-            for t in sorted(self.taxalist):
+            for t in sorted(self.taxa):
                 s = []
                 for c in sorted(self.characters):
                     value = self.data[c].get(t, self.MISSING)
@@ -109,7 +111,20 @@ class NexusWriter:
             self.data[character][taxon] += value
         else:
             self.data[character][taxon] = value
-
+    
+    def remove(self, taxon, character):
+        """Removes a `character` for the given `taxon` and sets it to empty"""
+        del(self.data[character][taxon])
+    
+    def remove_taxon(self, taxon):
+        """Removes a given `taxon` from the nexus file"""
+        for char in self.data:
+            del(self.data[char][taxon])
+        
+    def remove_character(self, character):
+        """Removes a given `character` from the nexus file"""
+        del(self.data[character])
+        
     def write(self, interleave=False, charblock=False):
         """
         Generates a string representation of the nexus
@@ -135,12 +150,12 @@ class NexusWriter:
 
         :return: String
         """
-        assert len(self.data) > 0, "No data in nexus!"
-        assert len(self.taxalist) > 0, "No taxa in nexus!"
-        assert len(self.characters) > 0, "No characters in nexus!"
+        assert self.data, "No data in nexus!"
+        assert self.taxa, "No taxa in nexus!"
+        assert self.characters, "No characters in nexus!"
 
         return TEMPLATE.strip() % {
-            'ntax': len(self.taxalist),
+            'ntax': len(self.taxa),
             'nchar': len(self.characters),
             'charblock': self._make_charlabel_block() if charblock else '',
             'matrix': self._make_matrix_block(interleave=interleave),
@@ -156,17 +171,16 @@ class NexusWriter:
                       charblock=False):
         """
         Generates a string representation of the nexus
-
+        
         :param filename: Filename to store nexus as
         :type filename: String
         :param interleave: Generate interleaved matrix or not
         :type interleave: Boolean
         :param charblock: Include a characters block or not
         :type charblock: Boolean
-
+        
         :return: None
         """
-        # do this first, so we don't make an empty file if make_nexus fails
         nexus = self.make_nexus(interleave, charblock)
         with open(filename, 'w+') as handle:
             handle.write(nexus)
@@ -176,9 +190,9 @@ class NexusWriter:
         Generates a simple table of the nexus
         """
         out = []
-        for t in sorted(self.taxalist):
+        for t in sorted(self.taxa):
             s = []
-            for c in self.characters:
+            for c in sorted(self.characters):
                 value = self.data[c].get(t, self.MISSING)
                 if len(value) > 1:  # wrap equivocal states in ()'s
                     value = "(%s)" % value
@@ -199,5 +213,3 @@ class NexusWriter:
         out = self.make_nexus(interleave=False, charblock=True)
         n.read_string(out)
         return n
-
-
